@@ -54,8 +54,6 @@ struct bitmask *numa_all_cpus_ptr = NULL;
 static unsigned long *node_cpu_mask_v1[NUMA_NUM_NODES];
 struct bitmask **node_cpu_mask_v2;
 
-char *nodes_allowed_list = NULL;
-
 WEAK void numa_error(char *where);
 
 #ifdef __thread
@@ -95,6 +93,17 @@ numa_init(void)
 	memset(&numa_no_nodes, 0, sizeof(numa_no_nodes));
 }
 
+void
+numa_fini(void)
+{
+	if (numa_all_cpus_ptr)
+		numa_bitmask_free(numa_all_cpus_ptr);
+	if (numa_all_nodes_ptr)
+		numa_bitmask_free(numa_all_nodes_ptr);
+	if (numa_no_nodes_ptr)
+		numa_bitmask_free(numa_no_nodes_ptr);
+}
+
 /*
  * The following bitmask declarations, bitmask_*() routines, and associated
  * _setbit() and _getbit() routines are:
@@ -249,19 +258,19 @@ WEAK void numa_warn(int num, char *fmt, ...)
 
 static void setpol(int policy, struct bitmask *bmp)
 { 
-	if (set_mempolicy(policy, bmp->maskp, bmp->size) < 0)
+	if (set_mempolicy(policy, bmp->maskp, bmp->size + 1) < 0)
 		numa_error("set_mempolicy");
 } 
 
 static void getpol(int *oldpolicy, struct bitmask *bmp)
 { 
-	if (get_mempolicy(oldpolicy, bmp->maskp, bmp->size, 0, 0) < 0)
+	if (get_mempolicy(oldpolicy, bmp->maskp, bmp->size + 1, 0, 0) < 0)
 		numa_error("get_mempolicy");
 } 
 
 static void dombind(void *mem, size_t size, int pol, struct bitmask *bmp)
 { 
-	if (mbind(mem, size, pol, bmp ? bmp->maskp : NULL, bmp ? bmp->size : 0, 
+	if (mbind(mem, size, pol, bmp ? bmp->maskp : NULL, bmp ? bmp->size + 1 : 0,
 		  mbind_flags) < 0)
 		numa_error("mbind"); 
 } 
@@ -431,7 +440,7 @@ read_mask(char *s, struct bitmask *bmp)
  * /proc/self/status.
  */
 static void
-set_thread_constraints(void)
+set_task_constraints(void)
 {
 	int hicpu = sysconf(_SC_NPROCESSORS_CONF)-1;
 	int i;
@@ -460,12 +469,6 @@ set_thread_constraints(void)
 			maxprocnode =
 				read_mask(mask, numa_all_nodes_ptr);
 		}
-		if (strncmp(buffer,"Mems_allowed_list:",18) == 0) {
-			nodes_allowed_list = malloc(strlen(buffer)-18);
-			strncpy(nodes_allowed_list, buffer + 19,
-				strlen(buffer) - 19);
-			nodes_allowed_list[strlen(nodes_allowed_list)-1] = '\0';
-		}
 	}
 	fclose(f);
 	free(buffer);
@@ -533,7 +536,6 @@ set_numa_max_cpu(void)
 static void
 set_configured_cpus(void)
 {
-	int		filecount=0;
 	char		*dirnamep = "/sys/devices/system/cpu";
 	struct dirent	*dirent;
 	DIR		*dir;
@@ -545,15 +547,19 @@ set_configured_cpus(void)
 		return;
 	}
 	while ((dirent = readdir(dir)) != 0) {
-		if (!strncmp("cpu", dirent->d_name, 3)) {
-			filecount++;
-		} else {
-			continue;
+		if (dirent->d_type == DT_DIR
+		    && !strncmp("cpu", dirent->d_name, 3)) {
+			long cpu = strtol(dirent->d_name + 3, NULL, 10);
+
+			if (cpu < INT_MAX && cpu > maxconfiguredcpu)
+				maxconfiguredcpu = cpu;
 		}
 	}
 	closedir(dir);
-	maxconfiguredcpu = filecount-1; /* high cpu number */
-	return;
+	if (maxconfiguredcpu < 0) {
+		/* fall back to using the online cpu count */
+		maxconfiguredcpu = sysconf(_SC_NPROCESSORS_CONF) - 1;
+	}
 }
 
 /*
@@ -567,7 +573,7 @@ set_sizes(void)
 	set_nodemask_size();	/* size of kernel nodemask_t */
 	set_numa_max_cpu();	/* size of kernel cpumask_t */
 	set_configured_cpus();	/* cpus listed in /sys/devices/system/cpu */
-	set_thread_constraints(); /* cpus and nodes for current thread */
+	set_task_constraints(); /* cpus and nodes for current task */
 }
 
 int
@@ -596,13 +602,13 @@ numa_num_possible_cpus(void)
 }
 
 int
-numa_num_thread_nodes(void)
+numa_num_task_nodes(void)
 {
 	return maxprocnode+1;
 }
 
 int
-numa_num_thread_cpus(void)
+numa_num_task_cpus(void)
 {
 	return maxproccpu+1;
 }
@@ -1016,9 +1022,6 @@ copy_bitmask_to_bitmask(struct bitmask *bmpfrom, struct bitmask *bmpto)
 		memcpy(bmpto->maskp, bmpfrom->maskp, bytes);
 		memset(((char *)bmpto->maskp)+bytes, 0,
 					CPU_BYTES(bmpto->size)-bytes);
-	} else {
-		bytes = CPU_BYTES(bmpfrom->size);
-		memcpy(bmpto->maskp, bmpfrom->maskp, bytes);
 	}
 }
 
@@ -1075,7 +1078,7 @@ numa_get_membind_v2(void)
 } 
 __asm__(".symver numa_get_membind_v2,numa_get_membind@@libnuma_1.2");
 
-//TODO:  Cliff:  do I need a v1 nodemask_t version?
+//TODO:  do we need a v1 nodemask_t version?
 struct bitmask *numa_get_mems_allowed(void)
 {
 	struct bitmask *bmp;
@@ -1272,11 +1275,11 @@ numa_node_to_cpus_v2(int node, struct bitmask *buffer)
 
 	if (node_cpu_mask_v2[node]) {
 		/* have already constructed a mask for this node */
-		if (buffer->size != node_cpu_mask_v2[node]->size) {
+		if (buffer->size < node_cpu_mask_v2[node]->size) {
 			numa_error("map size mismatch; abort\n");
 			return -1;
 		}
-		memcpy(buffer->maskp, node_cpu_mask_v2[node]->maskp, bufferlen);
+		copy_bitmask_to_bitmask(node_cpu_mask_v2[node], buffer);
 		return 0;
 	}
 
@@ -1667,7 +1670,7 @@ numa_parse_nodestring(char *s)
 	int maxnode = numa_max_node();
 	int invert = 0, relative = 0;
 	int conf_nodes = numa_num_configured_nodes();
-	int thread_nodes = numa_num_thread_nodes();
+	int task_nodes = numa_num_task_nodes();
 	char *end;
 	struct bitmask *mask;
 
@@ -1690,7 +1693,7 @@ numa_parse_nodestring(char *s)
 		int i;
 		if (!strcmp(s,"all")) {
 			int i;
-			for (i = 0; i < thread_nodes; i++)
+			for (i = 0; i < task_nodes; i++)
 				numa_bitmask_setbit(mask, i);
 			s+=4;
 			break;
@@ -1715,7 +1718,7 @@ numa_parse_nodestring(char *s)
 				numa_warn(W_nodeparse, "missing node argument %s\n", s);
 				goto err;
 			}
-			if (arg2 >= thread_nodes) {
+			if (arg2 >= task_nodes) {
 				numa_warn(W_nodeparse, "node argument %d out of range\n", arg2);
 				goto err;
 			}
@@ -1763,7 +1766,7 @@ numa_parse_cpustring(char *s)
 {
 	int invert = 0, relative=0;
 	int conf_cpus = numa_num_configured_cpus();
-	int thread_cpus = numa_num_thread_cpus();
+	int task_cpus = numa_num_task_cpus();
 	char *end;
 	struct bitmask *mask;
 
@@ -1785,7 +1788,7 @@ numa_parse_cpustring(char *s)
 
 		if (!strcmp(s,"all")) {
 			int i;
-			for (i = 0; i < thread_cpus; i++)
+			for (i = 0; i < task_cpus; i++)
 				numa_bitmask_setbit(mask, i);
 			s+=4;
 			break;
@@ -1795,7 +1798,7 @@ numa_parse_cpustring(char *s)
 			numa_warn(W_cpuparse, "unparseable cpu description `%s'\n", s);
 			goto err;
 		}
-		if (arg >= thread_cpus) {
+		if (arg >= task_cpus) {
 			numa_warn(W_cpuparse, "cpu argument %s is out of range\n", s);
 			goto err;
 		}
@@ -1811,7 +1814,7 @@ numa_parse_cpustring(char *s)
 				numa_warn(W_cpuparse, "missing cpu argument %s\n", s);
 				goto err;
 			}
-			if (arg2 >= thread_cpus) {
+			if (arg2 >= task_cpus) {
 				numa_warn(W_cpuparse, "cpu argument %s out of range\n", s);
 				goto err;
 			}
