@@ -11,7 +11,7 @@
    Lesser General Public License for more details.
 
    You should find a copy of v2.1 of the GNU Lesser General Public License
-   somewhere on your Linux system; if not, write to the Free Software 
+   somewhere on your Linux system; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
 #ifndef _NUMA_H
@@ -72,13 +72,13 @@ static inline void nodemask_zero(nodemask_t *mask)
 }
 
 static inline void nodemask_zero_compat(nodemask_t *mask)
-{ 
+{
 	struct bitmask tmp;
 
 	tmp.maskp = (unsigned long *)mask;
 	tmp.size = sizeof(nodemask_t) * 8;
 	numa_bitmask_clearall(&tmp);
-} 
+}
 
 static inline void nodemask_set_compat(nodemask_t *mask, int node)
 {
@@ -116,7 +116,7 @@ static inline int nodemask_equal(const nodemask_t *a, const nodemask_t *b)
 }
 
 static inline int nodemask_equal_compat(const nodemask_t *a, const nodemask_t *b)
-{ 
+{
 	struct bitmask tmp_a, tmp_b;
 
 	tmp_a.maskp = (unsigned long *)a;
@@ -126,7 +126,7 @@ static inline int nodemask_equal_compat(const nodemask_t *a, const nodemask_t *b
 	tmp_b.size = sizeof(nodemask_t) * 8;
 
 	return numa_bitmask_equal(&tmp_a, &tmp_b);
-} 
+}
 
 /* NUMA support available. If this returns a negative value all other function
    in this library are undefined. */
@@ -144,7 +144,7 @@ int numa_preferred(void);
 long long numa_node_size64(int node, long long *freep);
 long numa_node_size(int node, long *freep);
 
-int numa_pagesize(void); 
+int numa_pagesize(void);
 
 /* Set with all nodes. Only valid after numa_available. */
 extern struct bitmask *numa_all_nodes_ptr;
@@ -161,8 +161,6 @@ extern struct bitmask *numa_no_nodes_ptr;
 /* Source compatibility */
 extern nodemask_t numa_no_nodes;
 
-extern char *nodes_allowed_list;
-
 /* Only run and allocate memory from a specific set of nodes. */
 void numa_bind(struct bitmask *nodes);
 
@@ -180,16 +178,16 @@ static inline void numa_free_nodemask(struct bitmask *b)
 	numa_bitmask_free(b);
 }
 
-/* Some node to preferably allocate memory from for thread. */
+/* Some node to preferably allocate memory from for task. */
 void numa_set_preferred(int node);
 
-/* Set local memory allocation policy for thread */
+/* Set local memory allocation policy for task */
 void numa_set_localalloc(void);
 
 /* Only allocate memory from the nodes set in mask. 0 to turn off */
 void numa_set_membind(struct bitmask *nodemask);
 
-/* Return current membind */ 
+/* Return current membind */
 struct bitmask *numa_get_membind(void);
 
 /* Return allowed memories [nodes] */
@@ -200,7 +198,7 @@ int numa_get_interleave_node(void);
 /* NUMA memory allocation. These functions always round to page size
    and are relatively slow. */
 
-/* Alloc memory page interleaved on nodes in mask */ 
+/* Alloc memory page interleaved on nodes in mask */
 void *numa_alloc_interleaved_subset(size_t size, struct bitmask *nodemask);
 /* Alloc memory page interleaved on all nodes. */
 void *numa_alloc_interleaved(size_t size);
@@ -231,15 +229,15 @@ void numa_setlocal_memory(void *start, size_t size);
 /* Allocate memory area with current memory policy */
 void numa_police_memory(void *start, size_t size);
 
-/* Run current thread only on nodes in mask */
+/* Run current task only on nodes in mask */
 int numa_run_on_node_mask(struct bitmask *mask);
-/* Run current thread only on node */
+/* Run current task only on node */
 int numa_run_on_node(int node);
-/* Return current mask of nodes the thread can run on */
+/* Return current mask of nodes the task can run on */
 struct bitmask * numa_get_run_node_mask(void);
 
 /* When strict fail allocation when memory cannot be allocated in target node(s). */
-void numa_set_bind_policy(int strict);  
+void numa_set_bind_policy(int strict);
 
 /* Fail when existing memory has incompatible policy */
 void numa_set_strict(int flag);
@@ -284,9 +282,9 @@ int numa_distance(int node1, int node2);
    program. Default is to print an error to stderr and exit if numa_exit_on_error
    is true. */
 void numa_error(char *where);
- 
-/* When true exit the program when a NUMA system call (except numa_available) 
-   fails */ 
+
+/* When true exit the program when a NUMA system call (except numa_available)
+   fails */
 extern int numa_exit_on_error;
 /* Warning function. Can also be overwritten. Default is to print on stderr
    once. */
